import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ApiServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: ApiServiceMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: ApiServiceSpec[];
}
/**
 * @stability stable
 */
export interface ApiServiceMetadata {
    /**
     * An unstructured key value map stored with the api_service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the api_service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the api_service, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface ApiServiceSpecService {
    /**
     * Name is the name of the service.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Namespace is the namespace of the service.
     *
     * @stability stable
     */
    readonly namespace: string;
    /**
     * If specified, the port on the service that is hosting the service.
     *
     * Defaults to 443 for backward compatibility. Should be a valid port number (1-65535, inclusive).
     *
     * @stability stable
     */
    readonly port?: number;
}
/**
 * @stability stable
 */
export interface ApiServiceSpec {
    /**
     * CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate.
     *
     * If unspecified, system trust roots on the apiserver are used.
     *
     * @stability stable
     */
    readonly caBundle?: string;
    /**
     * Group is the API group name this server hosts.
     *
     * @stability stable
     */
    readonly group: string;
    /**
     * GroupPriorityMinimum is the priority this group should have at least.
     *
     * Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object. (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s.
     *
     * @stability stable
     */
    readonly groupPriorityMinimum: number;
    /**
     * InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server.
     *
     * This is strongly discouraged. You should use the CABundle instead.
     *
     * @stability stable
     */
    readonly insecureSkipTlsVerify?: boolean;
    /**
     * Version is the API version this server hosts.
     *
     * For example, `v1`.
     *
     * @stability stable
     */
    readonly version: string;
    /**
     * VersionPriority controls the ordering of this API version inside of its group.
     *
     * Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is `kube-like`, it will sort above non `kube-like` version strings, which are ordered lexicographically. `Kube-like` versions start with a `v`, then are followed by a number (the major version), then optionally the string `alpha` or `beta` and another number (the minor version). These are sorted first by GA > `beta` > `alpha` (where GA is a version with no suffix such as `beta` or `alpha`), and then by comparing major version, then minor version. An example sorted list of versions: `v10`, `v2`, `v1`, `v11beta2`, `v10beta3`, `v3beta1`, `v12alpha1`, `v11alpha2`, `foo1`, `foo10`.
     *
     * @stability stable
     */
    readonly versionPriority: number;
    /**
     * service block.
     *
     * @stability stable
     */
    readonly service?: ApiServiceSpecService[];
}
/**
 * @stability stable
 */
export declare class ApiService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ApiServiceMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: ApiServiceMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): ApiServiceMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): ApiServiceSpec[];
    /**
     * @stability stable
     */
    set spec(value: ApiServiceSpec[]);
    /**
     * @stability stable
     */
    get specInput(): ApiServiceSpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
