import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CertificateSigningRequestConfig extends cdktf.TerraformMetaArguments {
    /**
     * Automatically approve the CertificateSigningRequest.
     *
     * @stability stable
     */
    readonly autoApprove?: boolean;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: CertificateSigningRequestMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: CertificateSigningRequestSpec[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CertificateSigningRequestTimeouts;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestMetadata {
    /**
     * An unstructured key value map stored with the certificate signing request that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the certificate signing request.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the certificate signing request, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestSpec {
    /**
     * Base64-encoded PKCS#10 CSR data.
     *
     * @stability stable
     */
    readonly request: string;
    /**
     * Requested signer for the request.
     *
     * It is a qualified name in the form: `scope-hostname.io/name`.If empty, it will be defaulted: 1. If it's a kubelet client certificate, it is assigned `kubernetes.io/kube-apiserver-client-kubelet`.2. If it's a kubelet serving certificate, it is assigned `kubernetes.io/kubelet-serving`.3. Otherwise, it is assigned `kubernetes.io/legacy-unknown`. Distribution of trust for signers happens out of band.You can select on this field using `spec.signerName`.
     *
     * @stability stable
     */
    readonly signerName?: string;
    /**
     * allowedUsages specifies a set of usage contexts the key will be valid for.
     *
     * See: https://tools.ietf.org/html/rfc5280#section-4.2.1.3
     * https://tools.ietf.org/html/rfc5280#section-4.2.1.12
     * Valid values are:
     * "signing",
     * "digital signature",
     * "content commitment",
     * "key encipherment",
     * "key agreement",
     * "data encipherment",
     * "cert sign",
     * "crl sign",
     * "encipher only",
     * "decipher only",
     * "any",
     * "server auth",
     * "client auth",
     * "code signing",
     * "email protection",
     * "s/mime",
     * "ipsec end system",
     * "ipsec tunnel",
     * "ipsec user",
     * "timestamping",
     * "ocsp signing",
     * "microsoft sgc",
     * "netscape sgc"
     *
     * @stability stable
     */
    readonly usages?: string[];
}
/**
 * @stability stable
 */
export interface CertificateSigningRequestTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export declare class CertificateSigningRequest extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CertificateSigningRequestConfig);
    private _autoApprove?;
    /**
     * @stability stable
     */
    get autoApprove(): boolean;
    /**
     * @stability stable
     */
    set autoApprove(value: boolean);
    /**
     * @stability stable
     */
    resetAutoApprove(): void;
    /**
     * @stability stable
     */
    get autoApproveInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get certificate(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): CertificateSigningRequestMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: CertificateSigningRequestMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): CertificateSigningRequestMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): CertificateSigningRequestSpec[];
    /**
     * @stability stable
     */
    set spec(value: CertificateSigningRequestSpec[]);
    /**
     * @stability stable
     */
    get specInput(): CertificateSigningRequestSpec[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CertificateSigningRequestTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CertificateSigningRequestTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CertificateSigningRequestTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
