import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ClusterRoleBindingConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: ClusterRoleBindingMetadata[];
    /**
     * role_ref block.
     *
     * @stability stable
     */
    readonly roleRef: ClusterRoleBindingRoleRef[];
    /**
     * subject block.
     *
     * @stability stable
     */
    readonly subject: ClusterRoleBindingSubject[];
}
/**
 * @stability stable
 */
export interface ClusterRoleBindingMetadata {
    /**
     * An unstructured key value map stored with the clusterRoleBinding that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the clusterRoleBinding.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the clusterRoleBinding, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface ClusterRoleBindingRoleRef {
    /**
     * The API group of the user.
     *
     * The only value possible at the moment is `rbac.authorization.k8s.io`.
     *
     * @stability stable
     */
    readonly apiGroup: string;
    /**
     * The kind of resource.
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the User to bind to.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface ClusterRoleBindingSubject {
    /**
     * The API group of the subject resource.
     *
     * @stability stable
     */
    readonly apiGroup?: string;
    /**
     * The kind of resource.
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the resource to bind to.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The Namespace of the subject resource.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class ClusterRoleBinding extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ClusterRoleBindingConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ClusterRoleBindingMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: ClusterRoleBindingMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): ClusterRoleBindingMetadata[];
    private _roleRef;
    /**
     * @stability stable
     */
    get roleRef(): ClusterRoleBindingRoleRef[];
    /**
     * @stability stable
     */
    set roleRef(value: ClusterRoleBindingRoleRef[]);
    /**
     * @stability stable
     */
    get roleRefInput(): ClusterRoleBindingRoleRef[];
    private _subject;
    /**
     * @stability stable
     */
    get subject(): ClusterRoleBindingSubject[];
    /**
     * @stability stable
     */
    set subject(value: ClusterRoleBindingSubject[]);
    /**
     * @stability stable
     */
    get subjectInput(): ClusterRoleBindingSubject[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
