import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ConfigMapConfig extends cdktf.TerraformMetaArguments {
    /**
     * BinaryData contains the binary data.
     *
     * Each key must consist of alphanumeric characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the Data field, this is enforced during validation process. Using this field will require 1.10+ apiserver and kubelet. This field only accepts base64-encoded payloads that will be decoded/encoded before being sent/received to/from the apiserver.
     *
     * @stability stable
     */
    readonly binaryData?: {
        [key: string]: string;
    };
    /**
     * Data contains the configuration data.
     *
     * Each key must consist of alphanumeric characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in Data must not overlap with the keys in the BinaryData field, this is enforced during validation process.
     *
     * @stability stable
     */
    readonly data?: {
        [key: string]: string;
    };
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: ConfigMapMetadata[];
}
/**
 * @stability stable
 */
export interface ConfigMapMetadata {
    /**
     * An unstructured key value map stored with the config map that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the config map.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the config map, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the config map must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class ConfigMap extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConfigMapConfig);
    private _binaryData?;
    /**
     * @stability stable
     */
    get binaryData(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set binaryData(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetBinaryData(): void;
    /**
     * @stability stable
     */
    get binaryDataInput(): {
        [key: string]: string;
    } | undefined;
    private _data?;
    /**
     * @stability stable
     */
    get data(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set data(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetData(): void;
    /**
     * @stability stable
     */
    get dataInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ConfigMapMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: ConfigMapMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): ConfigMapMetadata[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
