import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CsiDriverConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: CsiDriverMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec?: CsiDriverSpec[];
}
/**
 * @stability stable
 */
export interface CsiDriverMetadata {
    /**
     * An unstructured key value map stored with the csi driver that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the csi driver.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the csi driver, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface CsiDriverSpec {
    /**
     * Indicates if the CSI volume driver requires an attach operation.
     *
     * @stability stable
     */
    readonly attachRequired: boolean;
    /**
     * Indicates that the CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations.
     *
     * @stability stable
     */
    readonly podInfoOnMount?: boolean;
    /**
     * Defines what kind of volumes this CSI volume driver supports.
     *
     * @stability stable
     */
    readonly volumeLifecycleModes?: string[];
}
/**
 * @stability stable
 */
export declare class CsiDriver extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CsiDriverConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): CsiDriverMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: CsiDriverMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): CsiDriverMetadata[];
    private _spec?;
    /**
     * @stability stable
     */
    get spec(): CsiDriverSpec[];
    /**
     * @stability stable
     */
    set spec(value: CsiDriverSpec[]);
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): CsiDriverSpec[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
