import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesConfigMapConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesConfigMapMetadata[];
}
/**
 * @stability stable
 */
export interface DataKubernetesConfigMapMetadata {
    /**
     * An unstructured key value map stored with the config_map that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the config_map.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the config_map, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the config_map must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesConfigMap extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesConfigMapConfig);
    /**
     * @stability stable
     */
    binaryData(key: string): string;
    /**
     * @stability stable
     */
    data(key: string): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesConfigMapMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: DataKubernetesConfigMapMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesConfigMapMetadata[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
