import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesNamespaceConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesNamespaceMetadata[];
}
/**
 * @stability stable
 */
export declare class DataKubernetesNamespaceSpec extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get finalizers(): string[];
}
/**
 * @stability stable
 */
export interface DataKubernetesNamespaceMetadata {
    /**
     * An unstructured key value map stored with the namespace that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the namespace.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the namespace, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesNamespace extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesNamespaceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    spec(index: string): DataKubernetesNamespaceSpec;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesNamespaceMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: DataKubernetesNamespaceMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesNamespaceMetadata[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
