import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesPersistentVolumeClaimConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesPersistentVolumeClaimMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec?: DataKubernetesPersistentVolumeClaimSpec[];
}
/**
 * @stability stable
 */
export interface DataKubernetesPersistentVolumeClaimMetadata {
    /**
     * An unstructured key value map stored with the persistent volume claim that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the persistent volume claim.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the persistent volume claim, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the persistent volume claim must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface DataKubernetesPersistentVolumeClaimSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DataKubernetesPersistentVolumeClaimSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: DataKubernetesPersistentVolumeClaimSpecSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface DataKubernetesPersistentVolumeClaimSpec {
    /**
     * Name of the storage class requested by the claim.
     *
     * @stability stable
     */
    readonly storageClassName?: string;
    /**
     * The binding reference to the PersistentVolume backing this claim.
     *
     * @stability stable
     */
    readonly volumeName?: string;
    /**
     * selector block.
     *
     * @stability stable
     */
    readonly selector?: DataKubernetesPersistentVolumeClaimSpecSelector[];
}
/**
 * @stability stable
 */
export declare class DataKubernetesPersistentVolumeClaim extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesPersistentVolumeClaimConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesPersistentVolumeClaimMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: DataKubernetesPersistentVolumeClaimMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesPersistentVolumeClaimMetadata[];
    private _spec?;
    /**
     * @stability stable
     */
    get spec(): DataKubernetesPersistentVolumeClaimSpec[];
    /**
     * @stability stable
     */
    set spec(value: DataKubernetesPersistentVolumeClaimSpec[]);
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): DataKubernetesPersistentVolumeClaimSpec[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
