import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassConfig extends cdktf.TerraformMetaArguments {
    /**
     * Indicates whether the storage class allow volume expand.
     *
     * @stability stable
     */
    readonly allowVolumeExpansion?: boolean;
    /**
     * Persistent Volumes that are dynamically created by a storage class will have the mount options specified.
     *
     * @stability stable
     */
    readonly mountOptions?: string[];
    /**
     * The parameters for the provisioner that should create volumes of this storage class.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * Indicates the type of the reclaim policy.
     *
     * @stability stable
     */
    readonly reclaimPolicy?: string;
    /**
     * Indicates when volume binding and dynamic provisioning should occur.
     *
     * @stability stable
     */
    readonly volumeBindingMode?: string;
    /**
     * allowed_topologies block.
     *
     * @stability stable
     */
    readonly allowedTopologies?: DataKubernetesStorageClassAllowedTopologies[];
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesStorageClassMetadata[];
}
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * An array of string values.
     *
     * One value must match the label to be selected.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassAllowedTopologies {
    /**
     * match_label_expressions block.
     *
     * @stability stable
     */
    readonly matchLabelExpressions?: DataKubernetesStorageClassAllowedTopologiesMatchLabelExpressions[];
}
/**
 * @stability stable
 */
export interface DataKubernetesStorageClassMetadata {
    /**
     * An unstructured key value map stored with the storage class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the storage class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the storage class, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesStorageClass extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesStorageClassConfig);
    private _allowVolumeExpansion?;
    /**
     * @stability stable
     */
    get allowVolumeExpansion(): boolean;
    /**
     * @stability stable
     */
    set allowVolumeExpansion(value: boolean);
    /**
     * @stability stable
     */
    resetAllowVolumeExpansion(): void;
    /**
     * @stability stable
     */
    get allowVolumeExpansionInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _mountOptions?;
    /**
     * @stability stable
     */
    get mountOptions(): string[];
    /**
     * @stability stable
     */
    set mountOptions(value: string[]);
    /**
     * @stability stable
     */
    resetMountOptions(): void;
    /**
     * @stability stable
     */
    get mountOptionsInput(): string[] | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _reclaimPolicy?;
    /**
     * @stability stable
     */
    get reclaimPolicy(): string;
    /**
     * @stability stable
     */
    set reclaimPolicy(value: string);
    /**
     * @stability stable
     */
    resetReclaimPolicy(): void;
    /**
     * @stability stable
     */
    get reclaimPolicyInput(): string | undefined;
    /**
     * @stability stable
     */
    get storageProvisioner(): string;
    private _volumeBindingMode?;
    /**
     * @stability stable
     */
    get volumeBindingMode(): string;
    /**
     * @stability stable
     */
    set volumeBindingMode(value: string);
    /**
     * @stability stable
     */
    resetVolumeBindingMode(): void;
    /**
     * @stability stable
     */
    get volumeBindingModeInput(): string | undefined;
    private _allowedTopologies?;
    /**
     * @stability stable
     */
    get allowedTopologies(): DataKubernetesStorageClassAllowedTopologies[];
    /**
     * @stability stable
     */
    set allowedTopologies(value: DataKubernetesStorageClassAllowedTopologies[]);
    /**
     * @stability stable
     */
    resetAllowedTopologies(): void;
    /**
     * @stability stable
     */
    get allowedTopologiesInput(): DataKubernetesStorageClassAllowedTopologies[] | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesStorageClassMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: DataKubernetesStorageClassMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesStorageClassMetadata[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
