import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: HorizontalPodAutoscalerMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: HorizontalPodAutoscalerSpec[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerMetadata {
    /**
     * An unstructured key value map stored with the horizontal pod autoscaler that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the horizontal pod autoscaler.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the horizontal pod autoscaler, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the horizontal pod autoscaler must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerSpecMetricExternalMetricSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalMetric {
    /**
     * name is the name of the given metric.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerSpecMetricExternalMetricSelector[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternalTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricExternal {
    /**
     * metric block.
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerSpecMetricExternalMetric[];
    /**
     * target block.
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricExternalTarget[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectDescribedObject {
    /**
     * API version of the referent.
     *
     * @stability stable
     */
    readonly apiVersion: string;
    /**
     * Kind of the referent;
     *
     * More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent;
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerSpecMetricObjectMetricSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectMetric {
    /**
     * name is the name of the given metric.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerSpecMetricObjectMetricSelector[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObjectTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricObject {
    /**
     * described_object block.
     *
     * @stability stable
     */
    readonly describedObject: HorizontalPodAutoscalerSpecMetricObjectDescribedObject[];
    /**
     * metric block.
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerSpecMetricObjectMetric[];
    /**
     * target block.
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricObjectTarget[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsMetricSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsMetricSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: HorizontalPodAutoscalerSpecMetricPodsMetricSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsMetric {
    /**
     * name is the name of the given metric.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * selector block.
     *
     * @stability stable
     */
    readonly selector?: HorizontalPodAutoscalerSpecMetricPodsMetricSelector[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPodsTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricPods {
    /**
     * metric block.
     *
     * @stability stable
     */
    readonly metric: HorizontalPodAutoscalerSpecMetricPodsMetric[];
    /**
     * target block.
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricPodsTarget[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricResourceTarget {
    /**
     * averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.
     *
     * Currently only valid for Resource metric source type
     *
     * @stability stable
     */
    readonly averageUtilization?: number;
    /**
     * averageValue is the target value of the average of the metric across all relevant pods (as a quantity).
     *
     * @stability stable
     */
    readonly averageValue?: string;
    /**
     * type represents whether the metric type is Utilization, Value, or AverageValue.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * value is the target value of the metric (as a quantity).
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetricResource {
    /**
     * name is the name of the resource in question.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * target block.
     *
     * @stability stable
     */
    readonly target?: HorizontalPodAutoscalerSpecMetricResourceTarget[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecMetric {
    /**
     * type is the type of metric source.
     *
     * It should be one of "Object", "Pods", "External" or "Resource", each mapping to a matching field in the object.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * external block.
     *
     * @stability stable
     */
    readonly external?: HorizontalPodAutoscalerSpecMetricExternal[];
    /**
     * object block.
     *
     * @stability stable
     */
    readonly object?: HorizontalPodAutoscalerSpecMetricObject[];
    /**
     * pods block.
     *
     * @stability stable
     */
    readonly pods?: HorizontalPodAutoscalerSpecMetricPods[];
    /**
     * resource block.
     *
     * @stability stable
     */
    readonly resource?: HorizontalPodAutoscalerSpecMetricResource[];
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpecScaleTargetRef {
    /**
     * API version of the referent.
     *
     * @stability stable
     */
    readonly apiVersion?: string;
    /**
     * Kind of the referent.
     *
     * e.g. `ReplicationController`. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#types-kinds
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface HorizontalPodAutoscalerSpec {
    /**
     * Upper limit for the number of pods that can be set by the autoscaler.
     *
     * @stability stable
     */
    readonly maxReplicas: number;
    /**
     * Lower limit for the number of pods that can be set by the autoscaler, defaults to `1`.
     *
     * @stability stable
     */
    readonly minReplicas?: number;
    /**
     * Target average CPU utilization (represented as a percentage of requested CPU) over all the pods.
     *
     * If not specified the default autoscaling policy will be used.
     *
     * @stability stable
     */
    readonly targetCpuUtilizationPercentage?: number;
    /**
     * metric block.
     *
     * @stability stable
     */
    readonly metric?: HorizontalPodAutoscalerSpecMetric[];
    /**
     * scale_target_ref block.
     *
     * @stability stable
     */
    readonly scaleTargetRef: HorizontalPodAutoscalerSpecScaleTargetRef[];
}
/**
 * @stability stable
 */
export declare class HorizontalPodAutoscaler extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HorizontalPodAutoscalerConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): HorizontalPodAutoscalerMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: HorizontalPodAutoscalerMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): HorizontalPodAutoscalerMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): HorizontalPodAutoscalerSpec[];
    /**
     * @stability stable
     */
    set spec(value: HorizontalPodAutoscalerSpec[]);
    /**
     * @stability stable
     */
    get specInput(): HorizontalPodAutoscalerSpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
