import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IngressConfig extends cdktf.TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     *
     * @stability stable
     */
    readonly waitForLoadBalancer?: boolean;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: IngressMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: IngressSpec[];
}
/**
 * @stability stable
 */
export declare class IngressStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class IngressStatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class IngressStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface IngressMetadata {
    /**
     * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the ingress, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the ingress must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface IngressSpecBackend {
    /**
     * Specifies the name of the referenced service.
     *
     * @stability stable
     */
    readonly serviceName?: string;
    /**
     * Specifies the port of the referenced service.
     *
     * @stability stable
     */
    readonly servicePort?: string;
}
/**
 * @stability stable
 */
export interface IngressSpecRuleHttpPathBackend {
    /**
     * Specifies the name of the referenced service.
     *
     * @stability stable
     */
    readonly serviceName?: string;
    /**
     * Specifies the port of the referenced service.
     *
     * @stability stable
     */
    readonly servicePort?: string;
}
/**
 * @stability stable
 */
export interface IngressSpecRuleHttpPath {
    /**
     * Path is matched against the path of an incoming request.
     *
     * Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. When unspecified, all paths from incoming requests are matched.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * backend block.
     *
     * @stability stable
     */
    readonly backend?: IngressSpecRuleHttpPathBackend[];
}
/**
 * @stability stable
 */
export interface IngressSpecRuleHttp {
    /**
     * path block.
     *
     * @stability stable
     */
    readonly path: IngressSpecRuleHttpPath[];
}
/**
 * @stability stable
 */
export interface IngressSpecRule {
    /**
     * Host is the fully qualified domain name of a network host, as defined by RFC 3986.
     *
     * Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
     * the IP in the Spec of the parent Ingress.
     * 2. The `:` delimiter is not respected because ports are not allowed.
     * Currently the port of an Ingress is implicitly :80 for http and
     * :443 for https.
     * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
     *
     * Host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If Host is precise, the request matches this rule if the http host header is equal to Host. 2. If Host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * http block.
     *
     * @stability stable
     */
    readonly http: IngressSpecRuleHttp[];
}
/**
 * @stability stable
 */
export interface IngressSpecTls {
    /**
     * Hosts are a list of hosts included in the TLS certificate.
     *
     * The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
     *
     * @stability stable
     */
    readonly hosts?: string[];
    /**
     * SecretName is the name of the secret used to terminate TLS traffic on port 443.
     *
     * Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
     *
     * @stability stable
     */
    readonly secretName?: string;
}
/**
 * @stability stable
 */
export interface IngressSpec {
    /**
     * IngressClassName is the name of the IngressClass cluster resource.
     *
     * The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
     *
     * @stability stable
     */
    readonly ingressClassName?: string;
    /**
     * backend block.
     *
     * @stability stable
     */
    readonly backend?: IngressSpecBackend[];
    /**
     * rule block.
     *
     * @stability stable
     */
    readonly rule?: IngressSpecRule[];
    /**
     * tls block.
     *
     * @stability stable
     */
    readonly tls?: IngressSpecTls[];
}
/**
 * @stability stable
 */
export declare class Ingress extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IngressConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    status(index: string): IngressStatus;
    private _waitForLoadBalancer?;
    /**
     * @stability stable
     */
    get waitForLoadBalancer(): boolean;
    /**
     * @stability stable
     */
    set waitForLoadBalancer(value: boolean);
    /**
     * @stability stable
     */
    resetWaitForLoadBalancer(): void;
    /**
     * @stability stable
     */
    get waitForLoadBalancerInput(): boolean | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): IngressMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: IngressMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): IngressMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): IngressSpec[];
    /**
     * @stability stable
     */
    set spec(value: IngressSpec[]);
    /**
     * @stability stable
     */
    get specInput(): IngressSpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
