import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KubernetesProviderConfig {
    /**
     * PEM-encoded client certificate for TLS authentication.
     *
     * @stability stable
     */
    readonly clientCertificate?: string;
    /**
     * PEM-encoded client certificate key for TLS authentication.
     *
     * @stability stable
     */
    readonly clientKey?: string;
    /**
     * PEM-encoded root certificates bundle for TLS authentication.
     *
     * @stability stable
     */
    readonly clusterCaCertificate?: string;
    /**
     * @stability stable
     */
    readonly configContext?: string;
    /**
     * @stability stable
     */
    readonly configContextAuthInfo?: string;
    /**
     * @stability stable
     */
    readonly configContextCluster?: string;
    /**
     * Path to the kube config file.
     *
     * Can be set with KUBE_CONFIG_PATH.
     *
     * @stability stable
     */
    readonly configPath?: string;
    /**
     * A list of paths to kube config files.
     *
     * Can be set with KUBE_CONFIG_PATHS environment variable.
     *
     * @stability stable
     */
    readonly configPaths?: string[];
    /**
     * The hostname (in form of URI) of Kubernetes master.
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Whether server should be accessed without verifying the TLS certificate.
     *
     * @stability stable
     */
    readonly insecure?: boolean;
    /**
     * The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * Token to authenticate an service account.
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * @stability stable
     */
    readonly username?: string;
    /**
     * Alias name.
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * exec block.
     *
     * @stability stable
     */
    readonly exec?: KubernetesProviderExec[];
}
/**
 * @stability stable
 */
export interface KubernetesProviderExec {
    /**
     * @stability stable
     */
    readonly apiVersion: string;
    /**
     * @stability stable
     */
    readonly args?: string[];
    /**
     * @stability stable
     */
    readonly command: string;
    /**
     * @stability stable
     */
    readonly env?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export declare class KubernetesProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: KubernetesProviderConfig);
    private _clientCertificate?;
    /**
     * @stability stable
     */
    get clientCertificate(): string | undefined;
    /**
     * @stability stable
     */
    set clientCertificate(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientCertificate(): void;
    /**
     * @stability stable
     */
    get clientCertificateInput(): string | undefined;
    private _clientKey?;
    /**
     * @stability stable
     */
    get clientKey(): string | undefined;
    /**
     * @stability stable
     */
    set clientKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetClientKey(): void;
    /**
     * @stability stable
     */
    get clientKeyInput(): string | undefined;
    private _clusterCaCertificate?;
    /**
     * @stability stable
     */
    get clusterCaCertificate(): string | undefined;
    /**
     * @stability stable
     */
    set clusterCaCertificate(value: string | undefined);
    /**
     * @stability stable
     */
    resetClusterCaCertificate(): void;
    /**
     * @stability stable
     */
    get clusterCaCertificateInput(): string | undefined;
    private _configContext?;
    /**
     * @stability stable
     */
    get configContext(): string | undefined;
    /**
     * @stability stable
     */
    set configContext(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigContext(): void;
    /**
     * @stability stable
     */
    get configContextInput(): string | undefined;
    private _configContextAuthInfo?;
    /**
     * @stability stable
     */
    get configContextAuthInfo(): string | undefined;
    /**
     * @stability stable
     */
    set configContextAuthInfo(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigContextAuthInfo(): void;
    /**
     * @stability stable
     */
    get configContextAuthInfoInput(): string | undefined;
    private _configContextCluster?;
    /**
     * @stability stable
     */
    get configContextCluster(): string | undefined;
    /**
     * @stability stable
     */
    set configContextCluster(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigContextCluster(): void;
    /**
     * @stability stable
     */
    get configContextClusterInput(): string | undefined;
    private _configPath?;
    /**
     * @stability stable
     */
    get configPath(): string | undefined;
    /**
     * @stability stable
     */
    set configPath(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfigPath(): void;
    /**
     * @stability stable
     */
    get configPathInput(): string | undefined;
    private _configPaths?;
    /**
     * @stability stable
     */
    get configPaths(): string[] | undefined;
    /**
     * @stability stable
     */
    set configPaths(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetConfigPaths(): void;
    /**
     * @stability stable
     */
    get configPathsInput(): string[] | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string | undefined;
    /**
     * @stability stable
     */
    set host(value: string | undefined);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _insecure?;
    /**
     * @stability stable
     */
    get insecure(): boolean | undefined;
    /**
     * @stability stable
     */
    set insecure(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetInsecure(): void;
    /**
     * @stability stable
     */
    get insecureInput(): boolean | undefined;
    private _password?;
    /**
     * @stability stable
     */
    get password(): string | undefined;
    /**
     * @stability stable
     */
    set password(value: string | undefined);
    /**
     * @stability stable
     */
    resetPassword(): void;
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string | undefined;
    /**
     * @stability stable
     */
    set username(value: string | undefined);
    /**
     * @stability stable
     */
    resetUsername(): void;
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _exec?;
    /**
     * @stability stable
     */
    get exec(): KubernetesProviderExec[] | undefined;
    /**
     * @stability stable
     */
    set exec(value: KubernetesProviderExec[] | undefined);
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): KubernetesProviderExec[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
