import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NamespaceConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: NamespaceMetadata[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: NamespaceTimeouts;
}
/**
 * @stability stable
 */
export interface NamespaceMetadata {
    /**
     * An unstructured key value map stored with the namespace that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the namespace.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the namespace, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface NamespaceTimeouts {
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class Namespace extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NamespaceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): NamespaceMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: NamespaceMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): NamespaceMetadata[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): NamespaceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: NamespaceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): NamespaceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
