import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NetworkPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: NetworkPolicyMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: NetworkPolicySpec[];
}
/**
 * @stability stable
 */
export interface NetworkPolicyMetadata {
    /**
     * An unstructured key value map stored with the network policy that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the network policy.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the network policy, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the network policy must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressPorts {
    /**
     * The port on the given protocol.
     *
     * This can either be a numerical or named port on a pod. If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * The protocol (TCP, UDP, or SCTP) which traffic must match.
     *
     * If not specified, this field defaults to TCP.
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressToIpBlock {
    /**
     * CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64".
     *
     * @stability stable
     */
    readonly cidr?: string;
    /**
     * Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64" Except values will be rejected if they are outside the CIDR range.
     *
     * @stability stable
     */
    readonly except?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressToNamespaceSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressToNamespaceSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: NetworkPolicySpecEgressToNamespaceSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressToPodSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressToPodSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: NetworkPolicySpecEgressToPodSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgressTo {
    /**
     * ip_block block.
     *
     * @stability stable
     */
    readonly ipBlock?: NetworkPolicySpecEgressToIpBlock[];
    /**
     * namespace_selector block.
     *
     * @stability stable
     */
    readonly namespaceSelector?: NetworkPolicySpecEgressToNamespaceSelector[];
    /**
     * pod_selector block.
     *
     * @stability stable
     */
    readonly podSelector?: NetworkPolicySpecEgressToPodSelector[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecEgress {
    /**
     * ports block.
     *
     * @stability stable
     */
    readonly ports?: NetworkPolicySpecEgressPorts[];
    /**
     * to block.
     *
     * @stability stable
     */
    readonly to?: NetworkPolicySpecEgressTo[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressFromIpBlock {
    /**
     * CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64".
     *
     * @stability stable
     */
    readonly cidr?: string;
    /**
     * Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64" Except values will be rejected if they are outside the CIDR range.
     *
     * @stability stable
     */
    readonly except?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressFromNamespaceSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressFromNamespaceSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: NetworkPolicySpecIngressFromNamespaceSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressFromPodSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressFromPodSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: NetworkPolicySpecIngressFromPodSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressFrom {
    /**
     * ip_block block.
     *
     * @stability stable
     */
    readonly ipBlock?: NetworkPolicySpecIngressFromIpBlock[];
    /**
     * namespace_selector block.
     *
     * @stability stable
     */
    readonly namespaceSelector?: NetworkPolicySpecIngressFromNamespaceSelector[];
    /**
     * pod_selector block.
     *
     * @stability stable
     */
    readonly podSelector?: NetworkPolicySpecIngressFromPodSelector[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngressPorts {
    /**
     * The port on the given protocol.
     *
     * This can either be a numerical or named port on a pod. If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * The protocol (TCP, UDP, or SCTP) which traffic must match.
     *
     * If not specified, this field defaults to TCP.
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecIngress {
    /**
     * from block.
     *
     * @stability stable
     */
    readonly from?: NetworkPolicySpecIngressFrom[];
    /**
     * ports block.
     *
     * @stability stable
     */
    readonly ports?: NetworkPolicySpecIngressPorts[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecPodSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpecPodSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: NetworkPolicySpecPodSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface NetworkPolicySpec {
    /**
     * List of rule types that the NetworkPolicy relates to.
     *
     * Valid options are ["Ingress"], ["Egress"], or ["Ingress", "Egress"]. If this field is not specified, it will default based on the existence of Ingress or Egress rules; policies that contain an Egress section are assumed to affect Egress, and all policies (whether or not they contain an Ingress section) are assumed to affect Ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an Egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8
     *
     * @stability stable
     */
    readonly policyTypes: string[];
    /**
     * egress block.
     *
     * @stability stable
     */
    readonly egress?: NetworkPolicySpecEgress[];
    /**
     * ingress block.
     *
     * @stability stable
     */
    readonly ingress?: NetworkPolicySpecIngress[];
    /**
     * pod_selector block.
     *
     * @stability stable
     */
    readonly podSelector: NetworkPolicySpecPodSelector[];
}
/**
 * @stability stable
 */
export declare class NetworkPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NetworkPolicyConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): NetworkPolicyMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: NetworkPolicyMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): NetworkPolicyMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): NetworkPolicySpec[];
    /**
     * @stability stable
     */
    set spec(value: NetworkPolicySpec[]);
    /**
     * @stability stable
     */
    get specInput(): NetworkPolicySpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
