import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PersistentVolumeClaimConfig extends cdktf.TerraformMetaArguments {
    /**
     * Whether to wait for the claim to reach `Bound` state (to find volume in which to claim the space).
     *
     * @stability stable
     */
    readonly waitUntilBound?: boolean;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: PersistentVolumeClaimMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: PersistentVolumeClaimSpec[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: PersistentVolumeClaimTimeouts;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimMetadata {
    /**
     * An unstructured key value map stored with the persistent volume claim that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the persistent volume claim.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the persistent volume claim, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the persistent volume claim must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimSpecResources {
    /**
     * Map describing the maximum amount of compute resources allowed.
     *
     * More info: http://kubernetes.io/docs/user-guide/compute-resources/
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    };
    /**
     * Map describing the minimum amount of compute resources required.
     *
     * If this is omitted for a container, it defaults to `limits` if that is explicitly specified, otherwise to an implementation-defined value. More info: http://kubernetes.io/docs/user-guide/compute-resources/
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: PersistentVolumeClaimSpecSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimSpec {
    /**
     * A set of the desired access modes the volume should have.
     *
     * More info: http://kubernetes.io/docs/user-guide/persistent-volumes#access-modes-1
     *
     * @stability stable
     */
    readonly accessModes: string[];
    /**
     * Name of the storage class requested by the claim.
     *
     * @stability stable
     */
    readonly storageClassName?: string;
    /**
     * The binding reference to the PersistentVolume backing this claim.
     *
     * @stability stable
     */
    readonly volumeName?: string;
    /**
     * resources block.
     *
     * @stability stable
     */
    readonly resources: PersistentVolumeClaimSpecResources[];
    /**
     * selector block.
     *
     * @stability stable
     */
    readonly selector?: PersistentVolumeClaimSpecSelector[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeClaimTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export declare class PersistentVolumeClaim extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PersistentVolumeClaimConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _waitUntilBound?;
    /**
     * @stability stable
     */
    get waitUntilBound(): boolean;
    /**
     * @stability stable
     */
    set waitUntilBound(value: boolean);
    /**
     * @stability stable
     */
    resetWaitUntilBound(): void;
    /**
     * @stability stable
     */
    get waitUntilBoundInput(): boolean | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PersistentVolumeClaimMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: PersistentVolumeClaimMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): PersistentVolumeClaimMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PersistentVolumeClaimSpec[];
    /**
     * @stability stable
     */
    set spec(value: PersistentVolumeClaimSpec[]);
    /**
     * @stability stable
     */
    get specInput(): PersistentVolumeClaimSpec[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PersistentVolumeClaimTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PersistentVolumeClaimTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PersistentVolumeClaimTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
