import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PersistentVolumeConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: PersistentVolumeMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: PersistentVolumeSpec[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: PersistentVolumeTimeouts;
}
/**
 * @stability stable
 */
export interface PersistentVolumeMetadata {
    /**
     * An unstructured key value map stored with the persistent volume that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the persistent volume.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the persistent volume, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecClaimRef {
    /**
     * The name of the PersistentVolumeClaim.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The namespace of the PersistentVolumeClaim.
     *
     * Uses 'default' namespace if none is specified.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecNodeAffinityRequiredNodeSelectorTermMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists`, `DoesNotExist`, `Gt`, and `Lt`.
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecNodeAffinityRequiredNodeSelectorTermMatchFields {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists`, `DoesNotExist`, `Gt`, and `Lt`.
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecNodeAffinityRequiredNodeSelectorTerm {
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: PersistentVolumeSpecNodeAffinityRequiredNodeSelectorTermMatchExpressions[];
    /**
     * match_fields block.
     *
     * @stability stable
     */
    readonly matchFields?: PersistentVolumeSpecNodeAffinityRequiredNodeSelectorTermMatchFields[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecNodeAffinityRequired {
    /**
     * node_selector_term block.
     *
     * @stability stable
     */
    readonly nodeSelectorTerm: PersistentVolumeSpecNodeAffinityRequiredNodeSelectorTerm[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecNodeAffinity {
    /**
     * required block.
     *
     * @stability stable
     */
    readonly required?: PersistentVolumeSpecNodeAffinityRequired[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceAwsElasticBlockStore {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Unique ID of the persistent disk resource in AWS (Amazon EBS volume).
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#awselasticblockstore
     *
     * @stability stable
     */
    readonly volumeId: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceAzureDisk {
    /**
     * Host Caching mode: None, Read Only, Read Write.
     *
     * @stability stable
     */
    readonly cachingMode: string;
    /**
     * The URI the data disk in the blob storage.
     *
     * @stability stable
     */
    readonly dataDiskUri: string;
    /**
     * The Name of the data disk in the blob storage.
     *
     * @stability stable
     */
    readonly diskName: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The type for the data disk.
     *
     * Expected values: Shared, Dedicated, Managed. Defaults to Shared
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceAzureFile {
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * The name of secret that contains Azure Storage Account Name and Key.
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * The namespace of the secret that contains Azure Storage Account Name and Key.
     *
     * For Kubernetes up to 1.18.x the default is the same as the Pod. For Kubernetes 1.19.x and later the default is "default" namespace.
     *
     * @stability stable
     */
    readonly secretNamespace?: string;
    /**
     * Share Name.
     *
     * @stability stable
     */
    readonly shareName: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCephFsSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCephFs {
    /**
     * Monitors is a collection of Ceph monitors More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * @stability stable
     */
    readonly monitors: string[];
    /**
     * Used as the mounted root, rather than the full Ceph tree, default is /.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to `false` (read/write). More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * The path to key ring for User, default is /etc/ceph/user.secret More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it.
     *
     * @stability stable
     */
    readonly secretFile?: string;
    /**
     * User is the rados user name, default is admin.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/cephfs/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * secret_ref block.
     *
     * @stability stable
     */
    readonly secretRef?: PersistentVolumeSpecPersistentVolumeSourceCephFsSecretRef[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCinder {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write). More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Volume ID used to identify the volume in Cinder.
     *
     * More info: http://releases.k8s.io/HEAD/examples/mysql-cinder-pd/README.md
     *
     * @stability stable
     */
    readonly volumeId: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCsiControllerExpandSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCsiControllerPublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCsiNodePublishSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCsiNodeStageSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceCsi {
    /**
     * the name of the volume driver to use.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Whether to set the read-only property in VolumeMounts to "true".
     *
     * If omitted, the default is "false". More info: http://kubernetes.io/docs/user-guide/volumes#csi
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Attributes of the volume to publish.
     *
     * @stability stable
     */
    readonly volumeAttributes?: {
        [key: string]: string;
    };
    /**
     * A string value that uniquely identifies the volume.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/volumes/#csi
     *
     * @stability stable
     */
    readonly volumeHandle: string;
    /**
     * controller_expand_secret_ref block.
     *
     * @stability stable
     */
    readonly controllerExpandSecretRef?: PersistentVolumeSpecPersistentVolumeSourceCsiControllerExpandSecretRef[];
    /**
     * controller_publish_secret_ref block.
     *
     * @stability stable
     */
    readonly controllerPublishSecretRef?: PersistentVolumeSpecPersistentVolumeSourceCsiControllerPublishSecretRef[];
    /**
     * node_publish_secret_ref block.
     *
     * @stability stable
     */
    readonly nodePublishSecretRef?: PersistentVolumeSpecPersistentVolumeSourceCsiNodePublishSecretRef[];
    /**
     * node_stage_secret_ref block.
     *
     * @stability stable
     */
    readonly nodeStageSecretRef?: PersistentVolumeSpecPersistentVolumeSourceCsiNodeStageSecretRef[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceFc {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * FC target lun number.
     *
     * @stability stable
     */
    readonly lun: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * FC target worldwide names (WWNs).
     *
     * @stability stable
     */
    readonly targetWwNs: string[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceFlexVolumeSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceFlexVolume {
    /**
     * Driver is the name of the driver to use for this volume.
     *
     * @stability stable
     */
    readonly driver: string;
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Extra command options if any.
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    };
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false (read/write).
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     *
     * @stability stable
     */
    readonly secretRef?: PersistentVolumeSpecPersistentVolumeSourceFlexVolumeSecretRef[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceFlocker {
    /**
     * Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.
     *
     * @stability stable
     */
    readonly datasetName?: string;
    /**
     * UUID of the dataset.
     *
     * This is unique identifier of a Flocker dataset
     *
     * @stability stable
     */
    readonly datasetUuid?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceGcePersistentDisk {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * The partition in the volume that you want to mount.
     *
     * If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * @stability stable
     */
    readonly partition?: number;
    /**
     * Unique name of the PD resource in GCE.
     *
     * Used to identify the disk in GCE. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * @stability stable
     */
    readonly pdName: string;
    /**
     * Whether to force the ReadOnly setting in VolumeMounts.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#gcepersistentdisk
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceGlusterfs {
    /**
     * The endpoint name that details Glusterfs topology.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     *
     * @stability stable
     */
    readonly endpointsName: string;
    /**
     * The Glusterfs volume path.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the Glusterfs volume to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/glusterfs/README.md#create-a-pod
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceHostPath {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#hostpath
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Type for HostPath volume.
     *
     * Allowed values are "" (default), DirectoryOrCreate, Directory, FileOrCreate, File, Socket, CharDevice and BlockDevice
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceIscsi {
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#iscsi
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Target iSCSI Qualified Name.
     *
     * @stability stable
     */
    readonly iqn: string;
    /**
     * iSCSI interface name that uses an iSCSI transport.
     *
     * Defaults to 'default' (tcp).
     *
     * @stability stable
     */
    readonly iscsiInterface?: string;
    /**
     * iSCSI target lun number.
     *
     * @stability stable
     */
    readonly lun?: number;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false.
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * iSCSI target portal.
     *
     * The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).
     *
     * @stability stable
     */
    readonly targetPortal: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceLocal {
    /**
     * Path of the directory on the host.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#local
     *
     * @stability stable
     */
    readonly path?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceNfs {
    /**
     * Path that is exported by the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Whether to force the NFS export to be mounted with read-only permissions.
     *
     * Defaults to false. More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Server is the hostname or IP address of the NFS server.
     *
     * More info: http://kubernetes.io/docs/user-guide/volumes#nfs
     *
     * @stability stable
     */
    readonly server: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourcePhotonPersistentDisk {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * ID that identifies Photon Controller persistent disk.
     *
     * @stability stable
     */
    readonly pdId: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceQuobyte {
    /**
     * Group to map volume access to Default is no group.
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * Whether to force the Quobyte volume to be mounted with read-only permissions.
     *
     * Defaults to false.
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.
     *
     * @stability stable
     */
    readonly registry: string;
    /**
     * User to map volume access to Defaults to serivceaccount user.
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * Volume is a string that references an already created Quobyte volume by name.
     *
     * @stability stable
     */
    readonly volume: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceRbdSecretRef {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceRbd {
    /**
     * A collection of Ceph monitors.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly cephMonitors: string[];
    /**
     * Filesystem type of the volume that you want to mount.
     *
     * Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: http://kubernetes.io/docs/user-guide/volumes#rbd
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Keyring is the path to key ring for RBDUser.
     *
     * Default is /etc/ceph/keyring. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly keyring?: string;
    /**
     * The rados user name.
     *
     * Default is admin. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly radosUser?: string;
    /**
     * The rados image name.
     *
     * More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly rbdImage: string;
    /**
     * The rados pool name.
     *
     * Default is rbd. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it.
     *
     * @stability stable
     */
    readonly rbdPool?: string;
    /**
     * Whether to force the read-only setting in VolumeMounts.
     *
     * Defaults to false. More info: http://releases.k8s.io/HEAD/examples/volumes/rbd/README.md#how-to-use-it
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * secret_ref block.
     *
     * @stability stable
     */
    readonly secretRef?: PersistentVolumeSpecPersistentVolumeSourceRbdSecretRef[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSourceVsphereVolume {
    /**
     * Filesystem type to mount.
     *
     * Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.
     *
     * @stability stable
     */
    readonly fsType?: string;
    /**
     * Path that identifies vSphere volume vmdk.
     *
     * @stability stable
     */
    readonly volumePath: string;
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpecPersistentVolumeSource {
    /**
     * aws_elastic_block_store block.
     *
     * @stability stable
     */
    readonly awsElasticBlockStore?: PersistentVolumeSpecPersistentVolumeSourceAwsElasticBlockStore[];
    /**
     * azure_disk block.
     *
     * @stability stable
     */
    readonly azureDisk?: PersistentVolumeSpecPersistentVolumeSourceAzureDisk[];
    /**
     * azure_file block.
     *
     * @stability stable
     */
    readonly azureFile?: PersistentVolumeSpecPersistentVolumeSourceAzureFile[];
    /**
     * ceph_fs block.
     *
     * @stability stable
     */
    readonly cephFs?: PersistentVolumeSpecPersistentVolumeSourceCephFs[];
    /**
     * cinder block.
     *
     * @stability stable
     */
    readonly cinder?: PersistentVolumeSpecPersistentVolumeSourceCinder[];
    /**
     * csi block.
     *
     * @stability stable
     */
    readonly csi?: PersistentVolumeSpecPersistentVolumeSourceCsi[];
    /**
     * fc block.
     *
     * @stability stable
     */
    readonly fc?: PersistentVolumeSpecPersistentVolumeSourceFc[];
    /**
     * flex_volume block.
     *
     * @stability stable
     */
    readonly flexVolume?: PersistentVolumeSpecPersistentVolumeSourceFlexVolume[];
    /**
     * flocker block.
     *
     * @stability stable
     */
    readonly flocker?: PersistentVolumeSpecPersistentVolumeSourceFlocker[];
    /**
     * gce_persistent_disk block.
     *
     * @stability stable
     */
    readonly gcePersistentDisk?: PersistentVolumeSpecPersistentVolumeSourceGcePersistentDisk[];
    /**
     * glusterfs block.
     *
     * @stability stable
     */
    readonly glusterfs?: PersistentVolumeSpecPersistentVolumeSourceGlusterfs[];
    /**
     * host_path block.
     *
     * @stability stable
     */
    readonly hostPath?: PersistentVolumeSpecPersistentVolumeSourceHostPath[];
    /**
     * iscsi block.
     *
     * @stability stable
     */
    readonly iscsi?: PersistentVolumeSpecPersistentVolumeSourceIscsi[];
    /**
     * local block.
     *
     * @stability stable
     */
    readonly local?: PersistentVolumeSpecPersistentVolumeSourceLocal[];
    /**
     * nfs block.
     *
     * @stability stable
     */
    readonly nfs?: PersistentVolumeSpecPersistentVolumeSourceNfs[];
    /**
     * photon_persistent_disk block.
     *
     * @stability stable
     */
    readonly photonPersistentDisk?: PersistentVolumeSpecPersistentVolumeSourcePhotonPersistentDisk[];
    /**
     * quobyte block.
     *
     * @stability stable
     */
    readonly quobyte?: PersistentVolumeSpecPersistentVolumeSourceQuobyte[];
    /**
     * rbd block.
     *
     * @stability stable
     */
    readonly rbd?: PersistentVolumeSpecPersistentVolumeSourceRbd[];
    /**
     * vsphere_volume block.
     *
     * @stability stable
     */
    readonly vsphereVolume?: PersistentVolumeSpecPersistentVolumeSourceVsphereVolume[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeSpec {
    /**
     * Contains all ways the volume can be mounted.
     *
     * More info: http://kubernetes.io/docs/user-guide/persistent-volumes#access-modes
     *
     * @stability stable
     */
    readonly accessModes: string[];
    /**
     * A description of the persistent volume's resources and capacity.
     *
     * More info: http://kubernetes.io/docs/user-guide/persistent-volumes#capacity
     *
     * @stability stable
     */
    readonly capacity: {
        [key: string]: string;
    };
    /**
     * A list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid.
     *
     * @stability stable
     */
    readonly mountOptions?: string[];
    /**
     * What happens to a persistent volume when released from its claim.
     *
     * Valid options are Retain (default) and Recycle. Recycling must be supported by the volume plugin underlying this persistent volume. More info: http://kubernetes.io/docs/user-guide/persistent-volumes#recycling-policy
     *
     * @stability stable
     */
    readonly persistentVolumeReclaimPolicy?: string;
    /**
     * A description of the persistent volume's class.
     *
     * More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#class
     *
     * @stability stable
     */
    readonly storageClassName?: string;
    /**
     * Defines if a volume is intended to be used with a formatted filesystem.
     *
     * or to remain in raw block state.
     *
     * @stability stable
     */
    readonly volumeMode?: string;
    /**
     * claim_ref block.
     *
     * @stability stable
     */
    readonly claimRef?: PersistentVolumeSpecClaimRef[];
    /**
     * node_affinity block.
     *
     * @stability stable
     */
    readonly nodeAffinity?: PersistentVolumeSpecNodeAffinity[];
    /**
     * persistent_volume_source block.
     *
     * @stability stable
     */
    readonly persistentVolumeSource: PersistentVolumeSpecPersistentVolumeSource[];
}
/**
 * @stability stable
 */
export interface PersistentVolumeTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export declare class PersistentVolume extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PersistentVolumeConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PersistentVolumeMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: PersistentVolumeMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): PersistentVolumeMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PersistentVolumeSpec[];
    /**
     * @stability stable
     */
    set spec(value: PersistentVolumeSpec[]);
    /**
     * @stability stable
     */
    get specInput(): PersistentVolumeSpec[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PersistentVolumeTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PersistentVolumeTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PersistentVolumeTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
