import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PodDisruptionBudgetConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: PodDisruptionBudgetMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: PodDisruptionBudgetSpec[];
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetMetadata {
    /**
     * An unstructured key value map stored with the pod disruption budget that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the pod disruption budget.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the pod disruption budget, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the pod disruption budget must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetSpecSelectorMatchExpressions {
    /**
     * The label key that the selector applies to.
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * A key's relationship to a set of values.
     *
     * Valid operators ard `In`, `NotIn`, `Exists` and `DoesNotExist`.
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * An array of string values.
     *
     * If the operator is `In` or `NotIn`, the values array must be non-empty. If the operator is `Exists` or `DoesNotExist`, the values array must be empty. This array is replaced during a strategic merge patch.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetSpecSelector {
    /**
     * A map of {key,value} pairs.
     *
     * A single {key,value} in the matchLabels map is equivalent to an element of `match_expressions`, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
     *
     * @stability stable
     */
    readonly matchLabels?: {
        [key: string]: string;
    };
    /**
     * match_expressions block.
     *
     * @stability stable
     */
    readonly matchExpressions?: PodDisruptionBudgetSpecSelectorMatchExpressions[];
}
/**
 * @stability stable
 */
export interface PodDisruptionBudgetSpec {
    /**
     * @stability stable
     */
    readonly maxUnavailable?: string;
    /**
     * @stability stable
     */
    readonly minAvailable?: string;
    /**
     * selector block.
     *
     * @stability stable
     */
    readonly selector: PodDisruptionBudgetSpecSelector[];
}
/**
 * @stability stable
 */
export declare class PodDisruptionBudget extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PodDisruptionBudgetConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PodDisruptionBudgetMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: PodDisruptionBudgetMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): PodDisruptionBudgetMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PodDisruptionBudgetSpec[];
    /**
     * @stability stable
     */
    set spec(value: PodDisruptionBudgetSpec[]);
    /**
     * @stability stable
     */
    get specInput(): PodDisruptionBudgetSpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
