import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PriorityClassConfig extends cdktf.TerraformMetaArguments {
    /**
     * An arbitrary string that usually provides guidelines on when this priority class should be used.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class.
     *
     * Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
     *
     * @stability stable
     */
    readonly globalDefault?: boolean;
    /**
     * The value of this priority class.
     *
     * This is the actual priority that pods receive when they have the name of this class in their pod spec.
     *
     * @stability stable
     */
    readonly value: number;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: PriorityClassMetadata[];
}
/**
 * @stability stable
 */
export interface PriorityClassMetadata {
    /**
     * An unstructured key value map stored with the priority class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the priority class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the priority class, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class PriorityClass extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PriorityClassConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _globalDefault?;
    /**
     * @stability stable
     */
    get globalDefault(): boolean;
    /**
     * @stability stable
     */
    set globalDefault(value: boolean);
    /**
     * @stability stable
     */
    resetGlobalDefault(): void;
    /**
     * @stability stable
     */
    get globalDefaultInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _value;
    /**
     * @stability stable
     */
    get value(): number;
    /**
     * @stability stable
     */
    set value(value: number);
    /**
     * @stability stable
     */
    get valueInput(): number;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PriorityClassMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: PriorityClassMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): PriorityClassMetadata[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
