import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ResourceQuotaConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: ResourceQuotaMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec?: ResourceQuotaSpec[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ResourceQuotaTimeouts;
}
/**
 * @stability stable
 */
export interface ResourceQuotaMetadata {
    /**
     * An unstructured key value map stored with the resource quota that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the resource quota.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the resource quota, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the resource quota must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface ResourceQuotaSpec {
    /**
     * The set of desired hard limits for each named resource.
     *
     * More info: http://releases.k8s.io/HEAD/docs/design/admission_control_resource_quota.md#admissioncontrol-plugin-resourcequota
     *
     * @stability stable
     */
    readonly hard?: {
        [key: string]: string;
    };
    /**
     * A collection of filters that must match each object tracked by a quota.
     *
     * If not specified, the quota matches all objects.
     *
     * @stability stable
     */
    readonly scopes?: string[];
}
/**
 * @stability stable
 */
export interface ResourceQuotaTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ResourceQuota extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ResourceQuotaConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ResourceQuotaMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: ResourceQuotaMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): ResourceQuotaMetadata[];
    private _spec?;
    /**
     * @stability stable
     */
    get spec(): ResourceQuotaSpec[];
    /**
     * @stability stable
     */
    set spec(value: ResourceQuotaSpec[]);
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): ResourceQuotaSpec[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ResourceQuotaTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ResourceQuotaTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ResourceQuotaTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
