import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RoleBindingConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: RoleBindingMetadata[];
    /**
     * role_ref block.
     *
     * @stability stable
     */
    readonly roleRef: RoleBindingRoleRef[];
    /**
     * subject block.
     *
     * @stability stable
     */
    readonly subject: RoleBindingSubject[];
}
/**
 * @stability stable
 */
export interface RoleBindingMetadata {
    /**
     * An unstructured key value map stored with the roleBinding that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the roleBinding.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the roleBinding, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the roleBinding must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface RoleBindingRoleRef {
    /**
     * The API group of the user.
     *
     * The only value possible at the moment is `rbac.authorization.k8s.io`.
     *
     * @stability stable
     */
    readonly apiGroup: string;
    /**
     * The kind of resource.
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the User to bind to.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface RoleBindingSubject {
    /**
     * The API group of the subject resource.
     *
     * @stability stable
     */
    readonly apiGroup?: string;
    /**
     * The kind of resource.
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * The name of the resource to bind to.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The Namespace of the subject resource.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class RoleBinding extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RoleBindingConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): RoleBindingMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: RoleBindingMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): RoleBindingMetadata[];
    private _roleRef;
    /**
     * @stability stable
     */
    get roleRef(): RoleBindingRoleRef[];
    /**
     * @stability stable
     */
    set roleRef(value: RoleBindingRoleRef[]);
    /**
     * @stability stable
     */
    get roleRefInput(): RoleBindingRoleRef[];
    private _subject;
    /**
     * @stability stable
     */
    get subject(): RoleBindingSubject[];
    /**
     * @stability stable
     */
    set subject(value: RoleBindingSubject[]);
    /**
     * @stability stable
     */
    get subjectInput(): RoleBindingSubject[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
