import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RoleConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: RoleMetadata[];
    /**
     * rule block.
     *
     * @stability stable
     */
    readonly rule: RoleRule[];
}
/**
 * @stability stable
 */
export interface RoleMetadata {
    /**
     * An unstructured key value map stored with the role that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the role.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the role, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the role must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface RoleRule {
    /**
     * Name of the APIGroup that contains the resources.
     *
     * @stability stable
     */
    readonly apiGroups: string[];
    /**
     * White list of names that the rule applies to.
     *
     * @stability stable
     */
    readonly resourceNames?: string[];
    /**
     * List of resources that the rule applies to.
     *
     * @stability stable
     */
    readonly resources: string[];
    /**
     * List of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.
     *
     * @stability stable
     */
    readonly verbs: string[];
}
/**
 * @stability stable
 */
export declare class Role extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RoleConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): RoleMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: RoleMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): RoleMetadata[];
    private _rule;
    /**
     * @stability stable
     */
    get rule(): RoleRule[];
    /**
     * @stability stable
     */
    set rule(value: RoleRule[]);
    /**
     * @stability stable
     */
    get ruleInput(): RoleRule[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
