import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SecretConfig extends cdktf.TerraformMetaArguments {
    /**
     * A map of the secret data in base64 encoding.
     *
     * Use this for binary data.
     *
     * @stability stable
     */
    readonly binaryData?: {
        [key: string]: string;
    };
    /**
     * A map of the secret data.
     *
     * @stability stable
     */
    readonly data?: {
        [key: string]: string;
    };
    /**
     * Type of secret.
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: SecretMetadata[];
}
/**
 * @stability stable
 */
export interface SecretMetadata {
    /**
     * An unstructured key value map stored with the secret that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the secret.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the secret, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the secret must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class Secret extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SecretConfig);
    private _binaryData?;
    /**
     * @stability stable
     */
    get binaryData(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set binaryData(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetBinaryData(): void;
    /**
     * @stability stable
     */
    get binaryDataInput(): {
        [key: string]: string;
    } | undefined;
    private _data?;
    /**
     * @stability stable
     */
    get data(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set data(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetData(): void;
    /**
     * @stability stable
     */
    get dataInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): SecretMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: SecretMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): SecretMetadata[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
