import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceAccountConfig extends cdktf.TerraformMetaArguments {
    /**
     * Enable automatic mounting of the service account token.
     *
     * @stability stable
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * image_pull_secret block.
     *
     * @stability stable
     */
    readonly imagePullSecret?: ServiceAccountImagePullSecret[];
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: ServiceAccountMetadata[];
    /**
     * secret block.
     *
     * @stability stable
     */
    readonly secret?: ServiceAccountSecret[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ServiceAccountTimeouts;
}
/**
 * @stability stable
 */
export interface ServiceAccountImagePullSecret {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface ServiceAccountMetadata {
    /**
     * An unstructured key value map stored with the service account that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service account.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the service account, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service account must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface ServiceAccountSecret {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface ServiceAccountTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export declare class ServiceAccount extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceAccountConfig);
    private _automountServiceAccountToken?;
    /**
     * @stability stable
     */
    get automountServiceAccountToken(): boolean;
    /**
     * @stability stable
     */
    set automountServiceAccountToken(value: boolean);
    /**
     * @stability stable
     */
    resetAutomountServiceAccountToken(): void;
    /**
     * @stability stable
     */
    get automountServiceAccountTokenInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get defaultSecretName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _imagePullSecret?;
    /**
     * @stability stable
     */
    get imagePullSecret(): ServiceAccountImagePullSecret[];
    /**
     * @stability stable
     */
    set imagePullSecret(value: ServiceAccountImagePullSecret[]);
    /**
     * @stability stable
     */
    resetImagePullSecret(): void;
    /**
     * @stability stable
     */
    get imagePullSecretInput(): ServiceAccountImagePullSecret[] | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ServiceAccountMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: ServiceAccountMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): ServiceAccountMetadata[];
    private _secret?;
    /**
     * @stability stable
     */
    get secret(): ServiceAccountSecret[];
    /**
     * @stability stable
     */
    set secret(value: ServiceAccountSecret[]);
    /**
     * @stability stable
     */
    resetSecret(): void;
    /**
     * @stability stable
     */
    get secretInput(): ServiceAccountSecret[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ServiceAccountTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ServiceAccountTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServiceAccountTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
