import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     *
     * @stability stable
     */
    readonly waitForLoadBalancer?: boolean;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata: ServiceMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: ServiceSpec[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ServiceTimeouts;
}
/**
 * @stability stable
 */
export declare class ServiceStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class ServiceStatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class ServiceStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface ServiceMetadata {
    /**
     * An unstructured key value map stored with the service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the service, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service must be unique.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface ServiceSpecPort {
    /**
     * The name of this port within the service.
     *
     * All ports within the service must have unique names. Optional if only one ServicePort is defined on this service.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The port on each node on which this service is exposed when `type` is `NodePort` or `LoadBalancer`.
     *
     * Usually assigned by the system. If specified, it will be allocated to the service if unused or else creation of the service will fail. Default is to auto-allocate a port if the `type` of this service requires one. More info: http://kubernetes.io/docs/user-guide/services#type--nodeport
     *
     * @stability stable
     */
    readonly nodePort?: number;
    /**
     * The port that will be exposed by this service.
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * The IP protocol for this port.
     *
     * Supports `TCP` and `UDP`. Default is `TCP`.
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Number or name of the port to access on the pods targeted by the service.
     *
     * Number must be in the range 1 to 65535. This field is ignored for services with `cluster_ip = "None"`. More info: http://kubernetes.io/docs/user-guide/services#defining-a-service
     *
     * @stability stable
     */
    readonly targetPort?: string;
}
/**
 * @stability stable
 */
export interface ServiceSpec {
    /**
     * The IP address of the service.
     *
     * It is usually assigned randomly by the master. If an address is specified manually and is not in use by others, it will be allocated to the service; otherwise, creation of the service will fail. `None` can be specified for headless services when proxying is not required. Ignored if type is `ExternalName`. More info: http://kubernetes.io/docs/user-guide/services#virtual-ips-and-service-proxies
     *
     * @stability stable
     */
    readonly clusterIp?: string;
    /**
     * A list of IP addresses for which nodes in the cluster will also accept traffic for this service.
     *
     * These IPs are not managed by Kubernetes. The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system.
     *
     * @stability stable
     */
    readonly externalIps?: string[];
    /**
     * The external reference that kubedns or equivalent will return as a CNAME record for this service.
     *
     * No proxying will be involved. Must be a valid DNS name and requires `type` to be `ExternalName`.
     *
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * Denotes if this Service desires to route external traffic to node-local or cluster-wide endpoints.
     *
     * `Local` preserves the client source IP and avoids a second hop for LoadBalancer and Nodeport type services, but risks potentially imbalanced traffic spreading. `Cluster` obscures the client source IP and may cause a second hop to another node, but should have good overall load-spreading. More info: https://kubernetes.io/docs/tutorials/services/source-ip/
     *
     * @stability stable
     */
    readonly externalTrafficPolicy?: string;
    /**
     * Specifies the Healthcheck NodePort for the service.
     *
     * Only effects when type is set to `LoadBalancer` and external_traffic_policy is set to `Local`.
     *
     * @stability stable
     */
    readonly healthCheckNodePort?: number;
    /**
     * Only applies to `type = LoadBalancer`.
     *
     * LoadBalancer will get created with the IP specified in this field. This feature depends on whether the underlying cloud-provider supports specifying this field when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature.
     *
     * @stability stable
     */
    readonly loadBalancerIp?: string;
    /**
     * If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs.
     *
     * This field will be ignored if the cloud-provider does not support the feature. More info: http://kubernetes.io/docs/user-guide/services-firewalls
     *
     * @stability stable
     */
    readonly loadBalancerSourceRanges?: string[];
    /**
     * When set to true, indicates that DNS implementations must publish the `notReadyAddresses` of subsets for the Endpoints associated with the Service.
     *
     * The default value is `false`. The primary use case for setting this field is to use a StatefulSet's Headless Service to propagate `SRV` records for its Pods without respect to their readiness for purpose of peer discovery.
     *
     * @stability stable
     */
    readonly publishNotReadyAddresses?: boolean;
    /**
     * Route service traffic to pods with label keys and values matching this selector.
     *
     * Only applies to types `ClusterIP`, `NodePort`, and `LoadBalancer`. More info: http://kubernetes.io/docs/user-guide/services#overview
     *
     * @stability stable
     */
    readonly selector?: {
        [key: string]: string;
    };
    /**
     * Used to maintain session affinity.
     *
     * Supports `ClientIP` and `None`. Defaults to `None`. More info: http://kubernetes.io/docs/user-guide/services#virtual-ips-and-service-proxies
     *
     * @stability stable
     */
    readonly sessionAffinity?: string;
    /**
     * Determines how the service is exposed.
     *
     * Defaults to `ClusterIP`. Valid options are `ExternalName`, `ClusterIP`, `NodePort`, and `LoadBalancer`. `ExternalName` maps to the specified `external_name`. More info: http://kubernetes.io/docs/user-guide/services#overview
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * port block.
     *
     * @stability stable
     */
    readonly port?: ServiceSpecPort[];
}
/**
 * @stability stable
 */
export interface ServiceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export declare class Service extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    status(index: string): ServiceStatus;
    private _waitForLoadBalancer?;
    /**
     * @stability stable
     */
    get waitForLoadBalancer(): boolean;
    /**
     * @stability stable
     */
    set waitForLoadBalancer(value: boolean);
    /**
     * @stability stable
     */
    resetWaitForLoadBalancer(): void;
    /**
     * @stability stable
     */
    get waitForLoadBalancerInput(): boolean | undefined;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): ServiceMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: ServiceMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): ServiceMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): ServiceSpec[];
    /**
     * @stability stable
     */
    set spec(value: ServiceSpec[]);
    /**
     * @stability stable
     */
    get specInput(): ServiceSpec[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ServiceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ServiceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
